# Beamr

_**B**eamer, **e**xcept **a**s **m**arkup, **r**eally!_

Beamr is a markup language (and interpreter thereof) for creating PDF slide shows from simple, easy to understand text files. It uses the full power of LaTeX and its Beamer document class.

[Installation and usage guide page](https://teonistor.github.io/beamr/)
